window.Gleam.initSearch([{"doc":"report","title":"report","content":"# report\n\n[![Package Version](https://img.shields.io/hexpm/v/report)](https://hex.pm/packages/report)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/report/)\n\nCreate informative &amp; beautiful source code reports.\n\n&gt; Note: this package is not ready for production yet.\n\n![example report output](./assets/example_output.png)\n\n## Usage\n\nInstall with the `gleam` CLI. This package works on all targets!\n\n```sh\ngleam add report\n```\n\nThe following code will display the demo report found in the image above.\n\n```gleam\nimport gleam/io\nimport report\n\n/// The source code to be annotated in the report.\nconst source = &quot;fizz₂ : Nat -&gt; String\nfizz₂ num =\n    case (mod num 5) (mod num 3) of\n        0 0 =&gt; \\&quot;FizzBuzz\\&quot;\n        0 _ =&gt; \\&quot;Fizz\\&quot;\n        _ 0 =&gt; \\&quot;Buzz\\&quot;\n        _ _ =&gt; num&quot;\n\npub fn main() {\n  let file = &quot;FizzBuzz.fun&quot;\n  let message = &quot;`case` clauses have incompatible types&quot;\n\n  // Labels add annotations to the source code. There is normally one primary\n  // label and any number of secondary and context labels.\n  let labels = [\n    report.primary_label(\n      message: &quot;expected `String`, found `Nat`&quot;,\n      from: #(7, 16),\n      to: #(7, 19),\n    ),\n    report.context_label(\n      message: &quot;`case` clauses have incompatible types&quot;,\n      from: #(3, 5),\n      to: #(7, 19),\n    ),\n    report.secondary_label(\n      message: &quot;this is found to be of type `String`&quot;,\n      from: #(4, 16),\n      to: #(4, 26),\n    ),\n    report.secondary_label(\n      message: &quot;this is found to be of type `String`&quot;,\n      from: #(5, 16),\n      to: #(5, 22),\n    ),\n    report.secondary_label(\n      message: &quot;this is found to be of type `String`&quot;,\n      from: #(6, 16),\n      to: #(6, 22),\n    ),\n    report.secondary_label(\n      message: &quot;expected type `String` found here&quot;,\n      from: #(1, 16),\n      to: #(1, 22),\n    ),\n  ]\n\n  // Additional information can be added to the end of a report.\n  let info = [\n    report.Rows(\n      rows: [#(&quot;expected type&quot;, &quot;String&quot;), #(&quot;found type&quot;, &quot;Nat&quot;)],\n      divider: &quot; = &quot;,\n    ),\n    report.Text(\n      &quot;All `case` clauses must evaluate to the same type, but the indicated branch does not have the same type as the others.&quot;,\n    ),\n  ]\n\n  // Create an error report. This could also be `report.warning` or `report.info`.\n  report.error(file:, source:, message:, labels:, info:)\n  // Finally, turn the report into a string with styling enabled then log the\n  // result to the console.\n  |&gt; report.to_string(style: True)\n  |&gt; io.println_error\n}\n```\n\nDocumentation can be found at &lt;https://hexdocs.pm/report&gt;.\n\n## Versioning\n\nThis package follows semver, but stylistic changes such as tweaking colors are not covered by a major version. There will be no breaking changes to the actual API without a major bump.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n\n## Inspiration\n\nThis package is inspired by similar projects such as [`hug`](https://hexdocs.pm/hug/), [`diagnose`](https://github.com/Mesabloo/diagnose), and [`codespan-reporting`](https://github.com/brendanzab/codespan). The example above is based on the example in `codespan-reporting`&#39;s README.\n","url":"index.html"},{"doc":"report","title":"Info","content":"pub type Info {\n  Text(message: String)\n  Note(prefix: String, message: String)\n  Rows(rows: List(#(String, String)), divider: String)\n}\n Some additional information attached to the end of a report.\nText(message: String)\n Results in the text passed in without any prefix. This is an improvement\n over simply appending text to the generated report since the message will\n be wrapped nicely on multiple lines as needed.\n\nNote(prefix: String, message: String)\n Results in `&lt;prefix&gt;: &lt;message&gt;`\n\nRows(rows: List(#(String, String)), divider: String)\n Create a formatted group of rows of text. The divider string  is inserted\n between each row *header* and *content*.\n\n \n Rows(\n   rows: [\n     #(&quot;expected type&quot;, &quot;SomeType&quot;),\n     #(&quot;found type&quot;, &quot;SomeOtherType&quot;),\n   ],\n   divider: &quot; = &quot;,\n )\n \n\n Rendered as (also would have additional styling):\n\n text\n expected type = SomeType\n    found type = SomeOtherType\n \n\nSynonyms:\nreport.Info\nreport Info","url":"report.html#Info"},{"doc":"report","title":"Label","content":"pub opaque type Label\n Create a label with functions ending in `_label`.\n\nSynonyms:\nreport.Label\nreport Label","url":"report.html#Label"},{"doc":"report","title":"Report","content":"pub opaque type Report\n Create a report with the [`error`](#error), [`warning`](#warning), and\n [`info`](#info) functions.\n\nSynonyms:\nreport.Report\nreport Report","url":"report.html#Report"},{"doc":"report","title":"context_label","content":"pub fn context_label(\n  message message: String,\n  from start: #(Int, Int),\n  to end: #(Int, Int),\n) -&gt; Label\n Create a *context* label. Context labels provide locational context to the\n report, normally by pointing out landmarks in the source code such as a\n surrounding list or function. This can be especially useful when reporting\n parsing errors:\n\n text\n foo([1, 2 3])\n     ┬     ━ I wanted a comma\n     ╰╴ in this list\n \nSynonyms:\nreport.context_label\nreport context_label","url":"report.html#context_label"},{"doc":"report","title":"error","content":"pub fn error(\n  file file: String,\n  source source: String,\n  message message: String,\n  labels labels: List(Label),\n  info info: List(Info),\n) -&gt; Report\n Create an error report.\n\n Parameters:\n - `file`: The name or path of the source file.\n - `source`: The source code of the file.\n - `message`: A short message describing the report, such as `Type mismatch`.\n - `labels`: A list of labels to annotate the source code. If multiple labels\n in the list overlap, the first in the list will take precedence.\n - `info`: A list of [`Info`](#Info) messages to add to the end of the report.\nSynonyms:\nreport.error\nreport error","url":"report.html#error"},{"doc":"report","title":"info","content":"pub fn info(\n  file file: String,\n  source source: String,\n  message message: String,\n  labels labels: List(Label),\n  info info: List(Info),\n) -&gt; Report\n Create an informational report.\n\n Parameters:\n - `file`: The name or path of the source file.\n - `source`: The source code of the file.\n - `message`: A short message describing the report.\n - `labels`: A list of labels to annotate the source code. If multiple labels\n in the list overlap, the first in the list will take precedence.\n - `info`: A list of [`Info`](#Info) messages to add to the end of the report.\nSynonyms:\nreport.info\nreport info","url":"report.html#info"},{"doc":"report","title":"primary_label","content":"pub fn primary_label(\n  message message: String,\n  from start: #(Int, Int),\n  to end: #(Int, Int),\n) -&gt; Label\n Create a *primary* label. Primary labels represent the main reason for the\n report (though multiple can be included as needed). The first primary label\n in the list of labels will have its location included in the report&#39;s header.\nSynonyms:\nreport.primary_label\nreport primary_label","url":"report.html#primary_label"},{"doc":"report","title":"secondary_label","content":"pub fn secondary_label(\n  message message: String,\n  from start: #(Int, Int),\n  to end: #(Int, Int),\n) -&gt; Label\n Create a *secondary* label. Secondary labels support the reason for the\n report by giving additional information and context.\nSynonyms:\nreport.secondary_label\nreport secondary_label","url":"report.html#secondary_label"},{"doc":"report","title":"to_string","content":"pub fn to_string(report: Report, style has_style: Bool) -&gt; String\n Transform a [`Report`](#Report) into a string, ready to be presented to the\n end user. Styling is optional but recommended for most use cases.\n\n \n report.error(...)\n |&gt; report.to_string(style: True)\n //-&gt; &quot;Error: ...&quot;\n \nSynonyms:\nreport.to_string\nreport to_string","url":"report.html#to_string"},{"doc":"report","title":"warning","content":"pub fn warning(\n  file file: String,\n  source source: String,\n  message message: String,\n  labels labels: List(Label),\n  info info: List(Info),\n) -&gt; Report\n Create a warning report.\n\n Parameters:\n - `file`: The name or path of the source file.\n - `source`: The source code of the file.\n - `message`: A short message describing the report, such as `Unused function`.\n - `labels`: A list of labels to annotate the source code. If multiple labels\n in the list overlap, the first in the list will take precedence.\n - `info`: A list of [`Info`](#Info) messages to add to the end of the report.\nSynonyms:\nreport.warning\nreport warning","url":"report.html#warning"},{"doc":"report","title":"report","content":"","url":"report.html"}]);